from pathlib import Path
from typing import List

import typer

from ldappy.core.lib.ldapur import LdapUr
from ldappy.tools.utils import Utils

app = typer.Typer()


@app.command()
def add(value: List[str] = typer.Argument(..., help="La ou les valeurs à ajouter dans `runUnivAuthorization`"),
        user: str = typer.Option(..., "--user", "-u", help="L'utilisateur recherché. \
                                                                Utilisation du dn ou du matricule siham."),
        flag: str = typer.Option("dn", "--flag", help="L'attribut qu'on utilise pour chercher l'utilisateur.\
                                                                Par défaut c'est le dn. \
                                                       Valeurs possibles : dn | matricule")):
    """ Ajoute une valeur ou une liste de valeur dans l'attribut `runUnivAuthorization` par rapport à un
    `dn` (distinguished name) donnée dans un Ldap.
    """
    ldap = LdapUr()
    if flag == "dn":
        result = ldap.add_authorization(value, dn=user)
        if result['success']:
            typer.echo(f"{result['debug']}")
        else:
            typer.echo(f"{result['debug']}", err=True)
            raise typer.Exit("L'opération a été interrompu")
    elif flag == "matricule":
        result = ldap.add_authorization_by_matricule(value, matricule=user)
        if result['success']:
            typer.echo(f"{result['debug']}")
        else:
            typer.echo(f"{result['debug']}", err=True)
            raise typer.Exit("L'opération a été interrompu")
    else:
        typer.echo(f"--u {flag} : inconnu", err=True)
        raise typer.Exit("L'opération a été interrompu")


@app.command()
def delete(value: List[str] = typer.Argument(..., help="La ou les valeurs à supprimer dans `runUnivAuthorization`"),
           user: str = typer.Option(..., "--user", "-u", help="L'utilisateur recherché. \
                                                                Utilisation du dn ou du matricule siham."),
           flag: str = typer.Option("dn", "--flag", help="L'attribut qu'on utilise pour chercher l'utilisateur.\
                                                                Par défaut c'est le dn. \
                                                       Valeurs possibles : dn | matricule")):
    """ Supprime une valeur ou une liste de valeur dans l'attribut `runUnivAuthorization` par rapport à un
    `dn` (distinguished name) donnée dans un Ldap.
    """

    ldap = LdapUr()
    if flag == "dn":
        result = ldap.delete_authorization(value, dn=user)
        if result['success']:
            typer.echo(f"{result['debug']}")
        else:
            typer.echo(f"{result['debug']}", err=True)
            raise typer.Abort("L'opération a été interrompu")
    elif flag == "matricule":
        result = ldap.delete_authorization_by_matricule(value, matricule=user)
        if result['success']:
            typer.echo(f"{result['debug']}")
        else:
            typer.echo(f"{result['debug']}", err=True)
            raise typer.Exit("L'opération a été interrompu")
    else:
        typer.echo(f"--id {flag} : inconnu", err=True)
        raise typer.Exit("L'opération a été interrompu")


@app.command()
def info(table: bool = typer.Option(False, "--list", "-l",
                                    help="Affiche un example de liste de valeur pour `runUnivAuthorization`")):
    """ Affiche les informations concernants l'attribut `runUnivAthorization`
    """
    if table:
        typer.echo("Liste des valeurs présentes dans `runUnivAuthorization` \n")

        ldap = LdapUr()
        t = ldap.get_all_value_specatt()
        tform = [v.split(':') for v in sorted(t)]

        Utils.lprint(tform, headers=['Application', 'Accès'])
    else:
        with open(Path("docs/authorization.md").resolve()) as md:
            typer.secho(md.read())

