import typer
import logging
from ldappy.app import authorization, structure, config

__version__ = "1.0.0"

logger = logging.getLogger(__name__)


def version_callback(value: bool):
    if value:
        typer.echo(f"Ldappy CLI version: {__version__}")
        raise typer.Exit()


app = typer.Typer()
app.add_typer(authorization.app,
              name='rununivauthorization',
              help="Manipulation de l'attribut `runUnivAthorization` disponible dans ldapR \
                    Ajout / Suppression de valeur",
              short_help="Manipulation de l'attribut")

app.add_typer(structure.app,
              name='uo',
              help="Voir et lister les UO (Unités Organisationnelles) qui sont disponible dans le ldap ",
              short_help="Recherche d'UO")

app.add_typer(config.app,
              name='configuration',
              help="Configuration des accès pour se connecter au ldap",
              short_help="Conf accès ldap")


@app.callback()
def main(
        version: bool = typer.Option(None, "--version", callback=version_callback, is_eager=True),
        verbose: bool = False
):
    if verbose:
        logging.getLogger('zeep').setLevel(logging.ERROR)
        logging.getLogger('urllib3').setLevel(logging.ERROR)

        logging.basicConfig(format='%(asctime)s :: %(name)s :: %(levelname)s :: %(message)s',
                            level=logging.DEBUG, handlers=[logging.StreamHandler()])
