import json
import csv
import pathlib
from typing import Dict, Union, List, Optional, Any

from tabulate import tabulate


class Utils:
    """ Boite à outil """

    @staticmethod
    def yaml_to_json(file: str) -> Dict[str, Union[str, int]]:
        """ Parse un fichier .yaml en dicrionnaire python

        Args:
            file (str): chemin du fichier yaml

        Returns:
            Dictionnaire contenant les informations du fichier yaml

        """
        # Open the file and load the file
        with open(file) as f:
            return yaml.load(f, Loader=SafeLoader)

    @staticmethod
    def lprint(array: List[Any], *, headers: Optional[Union[List, None]] = None) -> None:
        """ Beautiful print. Affiche une liste sous forme de tableau.

        Args:
            array (List): La liste 1-D à afficher sous forme de tableau dans la console
            headers (List, None): Optionnel. En-tête du tableau.
        Returns:
            Affiche un tableau dans la console
        """
        print(tabulate(array, headers=headers, tablefmt='pipe'))

    @staticmethod
    def jprint(jlist: List[Any]) -> None:
        """ Affiche une liste json de manière "pretty"

        Args:
            jlist (List): Une liste au format json
        """
        print(json.dumps(jlist, indent=2))

    @staticmethod
    def create_ldap_config(host: str, port: str, base: str, ldap_user: str,
                           ldap_password: str, *, pathfile: str = '../config/custom_ldap.yaml') -> None:
        """ Crée un fichier de configuration au format yaml pour le paramérage de l'accès au ldap
        """

        print(pathlib.Path().absolute())
        dict_file = [{'ldap': [
                        {'host': host},
                        {'port': port},
                        {'base': base},
                        {'ldap_user': ldap_user},
                        {'ldap_password': ldap_password}]}]

        with open(pathfile, 'w') as file:
            yaml.dump(dict_file, file)

    @staticmethod
    def json_to_csv(jlist: List[Any]) -> None:
        """ Transforme une liste json en fichier csv

        Args:
            jlist (List): Une liste au format json
        """
        with open('pt_data1.csv', 'w', newline='', encoding='utf-8') as pt_data1:
            csvwriter = csv.writer(pt_data1)

            for data in jlist:
                dn = data["dn"]
                prenom = data["attributes"]["runUnivPrenom"][0]
                nom = data["attributes"]["runUnivNom"][0]
                mail = data["attributes"]["mail"][0]
                login = data["attributes"]["supannAliasLogin"][0]
                affectation = data["attributes"]["supannEntiteAffectationPrincipale"][0]
                sihamid = data["attributes"]["runUnivSihamId"][0]

                csvwriter.writerow([prenom, nom, login, mail, affectation, sihamid, dn])
